@@ -49,21 +49,13 @@ namespace JSBSim {
 CLASS IMPLEMENTATION
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
 
-FGSurface::FGSurface(FGFDMExec* fdmex, int number) :
-   contactNumber(number)
+FGSurface::FGSurface(FGFDMExec* fdmex)
 {
-  _PropertyManager = fdmex->GetPropertyManager();
   resetValues();
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-FGSurface::~FGSurface()
-{
-}
-
-//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
 void FGSurface::resetValues(void)
 {
   staticFFactor = 1.0;
@@ -78,49 +70,27 @@ void FGSurface::resetValues(void)
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
-void FGSurface::bind(void)
+void FGSurface::bind(FGPropertyManager* PropertyManager)
 {
-  if (!_PropertyManager) return;
-
-  string base_property_name;
+  string base_property_name = "ground";
   string property_name;
 
-  switch(eSurfaceType) {
-  case ctBOGEY:
-    base_property_name = _CreateIndexedPropertyName("gear/unit", contactNumber);
-    break;
-  case ctSTRUCTURE:
-    base_property_name = _CreateIndexedPropertyName("contact/unit", contactNumber);
-    break;
-  case ctGROUND:
-    base_property_name = "ground";
-    break;
-  default:
-    return;
-  }
- 
   property_name = base_property_name + "/solid";
-  _PropertyManager->Tie( property_name.c_str(), &isSolid);
+  PropertyManager->Tie( property_name.c_str(), &isSolid);
   property_name = base_property_name + "/bumpiness";
-  _PropertyManager->Tie( property_name.c_str(), &bumpiness);
+  PropertyManager->Tie( property_name.c_str(), &bumpiness);
   property_name = base_property_name + "/maximum-force-lbs";
-  _PropertyManager->Tie( property_name.c_str(), &maximumForce);
+  PropertyManager->Tie( property_name.c_str(), &maximumForce);
   property_name = base_property_name + "/rolling_friction-factor";
-  _PropertyManager->Tie( property_name.c_str(), &rollingFFactor);
+  PropertyManager->Tie( property_name.c_str(), &rollingFFactor);
   property_name = base_property_name + "/static-friction-factor";
-  _PropertyManager->Tie( property_name.c_str(), &staticFFactor);
+  PropertyManager->Tie( property_name.c_str(), &staticFFactor);
 }
 
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 float FGSurface::GetBumpHeight()
 {
-  // bump hight might have been manually set
-  if (bumpHeight < DBL_MAX) {
-    float rv = bumpHeight;
-    bumpHeight = DBL_MAX;
-    return rv;
-  }
   if (bumpiness < 0.001) return 0.0f;
 
   double x = pos[0]*0.1;
@@ -141,43 +111,4 @@ float FGSurface::GetBumpHeight()
   return h*(1/8.)*bumpiness*maxGroundBumpAmplitude;
 }
 
-//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
-string FGSurface::_CreateIndexedPropertyName(const string& Property, int index)
-{
-  std::ostringstream buf;
-  buf << Property << '[' << index << ']';
-  return buf.str();
-}
-
-//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
-string FGSurface::GetSurfaceStrings(string delimeter) const
-{
-  std::ostringstream buf;
-
-  buf << "staticFFactor" << delimeter
-      << "rollingFFactor" << delimeter
-      << "maximumForce" << delimeter
-      << "bumpiness" << delimeter
-      << "isSolid";
-  
-  return buf.str();
-}
-
-//%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-
-string FGSurface::GetSurfaceValues(string delimeter) const
-{
-  std::ostringstream buf;
- 
-  buf << staticFFactor << delimeter
-      << rollingFFactor << delimeter
-      << maximumForce << delimeter
-      << bumpiness << delimeter
-      << (isSolid ? "1" : "0");
-
-  return buf.str();
-}
-
 } // namespace JSBSim
