@@ -42,8 +42,6 @@ INCLUDES
 
 #include "FGEngine.h"
 
-#define ID_TURBINE "$Id: FGTurbine.h,v 1.26 2015/09/27 10:07:53 bcoconni Exp $"
-
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 FORWARD DECLARATIONS
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%*/
@@ -68,8 +66,8 @@ CLASS DOCUMENTATION
 <P>
     - STARTING (on ground):
       -# Set the control FGEngine::Starter to true.  The engine will spin up to
-         a maximum of about %25 N2 (%5.2 N1).  This simulates the action of a
-         pneumatic starter.
+         a maximum of about %25 N2 (%5.2 N1). This value may be changed using the <startnX> parameter.
+		 This simulates the action of a pneumatic starter.
       -# After reaching %15 N2 set the control FGEngine::Cutoff to false. If fuel
          is available the engine will now accelerate to idle.  The starter will
          automatically be set to false after the start cycle.
@@ -80,7 +78,7 @@ CLASS DOCUMENTATION
       -# Place the control FGEngine::Cutoff to false.
 <P>
     Ignition is assumed to be on anytime the Cutoff control is set to false,
-    therefore a seperate ignition system is not modeled.
+    therefore a separate ignition system is not modeled.
 
 <h3>Configuration File Format:</h3>
 @code
@@ -91,16 +89,23 @@ CLASS DOCUMENTATION
   <bleed> {number} </bleed>
   <tsfc> {number} </tsfc>
   <atsfc> {number} </atsfc>
+  <ignitionn1> {number} </ignitionn1>
+  <ignitionn2> {number} </ignitionn2>
   <idlen1> {number} </idlen1>
   <idlen2> {number} </idlen2>
   <n1spinup> {number} </n1spinup>
   <n2spinup> {number} </n2spinup>
+  <n1startrate> {number} </n1startrate>
+  <n2startrate> {number} </n2startrate>
+  <n1spindown> {number} </n1spindown>
+  <n2spindown> {number} </n2spindown>
   <maxn1> {number} </maxn1>
   <maxn2> {number} </maxn2>
   <augmented> {0 | 1} </augmented>
   <augmethod> {0 | 1 | 2} </augmethod>
   <injected> {0 | 1} </injected>
   <injection-time> {number} </injection-time>
+  <disable-windmill> {0 | 1}</disable-windmill>
  </turbine_engine>
 @endcode
 
@@ -113,11 +118,17 @@ CLASS DOCUMENTATION
   bleed       - Thrust reduction factor due to losses (0.0 to 1.0).
   tsfc        - Thrust-specific fuel consumption at cruise, lbm/hr/lbf
   atsfc       - Afterburning TSFC, lbm/hr/lbf
+  ignitionn1  - Fan rotor rpm (% of max) while starting
+  ignitionn2  - Core rotor rpm (% of max) while starting
   idlen1      - Fan rotor rpm (% of max) at idle
   idlen2      - Core rotor rpm (% of max) at idle
-  n1spinup    - Fan rotor rpm starter acceleration (default 1.0)
-  n2spinup    - Core rotor rpm starter acceleration (default 3.0)
-  maxn1       - Fan rotor rpm (% of max) at full throttle 
+  n1spinup    - Fan rotor rpm starter acceleration to ignitionn1 value (default 1.0)
+  n2spinup    - Core rotor rpm starter acceleration to ignitionn2 value (default 3.0)
+  n1startrate - Fan rotor rpm time taken to accelerate from ignitionn1 to idlen1 value (default 1.4)
+  n2startrate - Core rotor rpm time taken to accelerate to ignitionn2 idlen2 value (default 2.0)
+  n1spindown  - Factor used in calculation for fan rotor time to spool down to zero (default 2.0)
+  n2spindown  - Factor used in calculation for core rotor time to spool down to zero (default 2.0)
+  maxn1       - Fan rotor rpm (% of max) at full throttle
   maxn2       - Core rotor rpm (% of max) at full throttle
   augmented
               0 = afterburner not installed
@@ -129,12 +140,13 @@ CLASS DOCUMENTATION
   injected
               0 = Water injection not installed
               1 = Water injection installed
-  injection-time - Time, in seconds, of water injection duration 
+  injection-time - Time, in seconds, of water injection duration
   InjN1increment - % increase in N1 when injection is taking place
   InjN2increment - % increase in N2 when injection is taking place
+  disable-windmill - flag that disables engine windmilling when off if true
 </pre>
 
-<h3>NOTES:</h3>  
+<h3>NOTES:</h3>
 <pre>
     Bypass ratio is used only to estimate engine acceleration time.  The
     effect of bypass ratio on engine efficiency is already included in
@@ -152,7 +164,6 @@ CLASS DOCUMENTATION
     /engine/direct.xml
 </pre>
     @author David P. Culp
-    @version "$Id: FGTurbine.h,v 1.26 2015/09/27 10:07:53 bcoconni Exp $"
 */
 
 /*%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -224,7 +235,7 @@ public:
   void SetInjWaterNorm(double injwater) {InjWaterNorm = injwater;}
   void SetInjN1increment(double injN1inc) {InjN1increment = injN1inc;}
   void SetInjN2increment(double injN2inc) {InjN2increment = injN2inc;}
-  
+
   int InitRunning(void);
   void ResetToIC(void);
 
@@ -241,6 +252,8 @@ private:
   double ATSFC;            ///< Augmented TSFC (lbm/hr/lbf)
   double IdleN1;           ///< Idle N1
   double IdleN2;           ///< Idle N2
+  double IgnitionN1;       ///< Ignition N1
+  double IgnitionN2;       ///< Ignition N2
   double N1;               ///< N1
   double N2;               ///< N2
   double N2norm;           ///< N2 normalized (0=idle, 1=max)
@@ -251,8 +264,12 @@ private:
   double N2_factor;        ///< factor to tie N2 and throttle
   double ThrottlePos;      ///< FCS-supplied throttle position - modified for local use!
   double AugmentCmd;       ///< modulated afterburner command (0.0 to 1.0)
-  double N1_spinup;        ///< N1 spin up rate from starter (per second)
-  double N2_spinup;        ///< N2 spin up rate from starter (per second)
+  double N1_spinup;        ///< N1 spin up rate from pneumatic starter (per second)
+  double N2_spinup;        ///< N2 spin up rate from pneumatic starter (per second)
+  double N1_start_rate;    ///< N1 spin up rate from ignition (per second)
+  double N2_start_rate;    ///< N2 spin up rate from ignition (per second)
+  double N1_spindown;      ///< N1 spin down factor
+  double N2_spindown;      ///< N2 spin down factor
   bool Stalled;            ///< true if engine is compressor-stalled
   bool Seized;             ///< true if inner spool is seized
   bool Overtemp;           ///< true if EGT exceeds limits
@@ -261,6 +278,7 @@ private:
   bool Augmentation;
   bool Reversed;
   bool Cutoff;
+  bool disableWindmill;    ///< flag to disable windmilling of engine in Off phase
   int Injected;            ///< = 1 if water injection installed
   int Ignition;
   int Augmented;           ///< = 1 if augmentation installed
@@ -311,7 +329,7 @@ class FGSpoolUp : public FGParameter
 public:
   FGSpoolUp(FGTurbine* _turb, double BPR, double factor)
     : turb(_turb), delay(factor * 90.0 / (BPR + 3.0)) {}
-  string GetName(void) const { return string(); };
+  std::string GetName(void) const { return std::string(); };
   double GetValue(void) const {
     // adjust acceleration for N2 and atmospheric density
     double n = std::min(1.0, turb->N2norm + 0.1);
@@ -324,4 +342,3 @@ private:
 }
 //%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 #endif
-
