@@ -28,6 +28,7 @@
 #include "test_suite/FGTestApi/NavDataCache.hxx"
 #include "test_suite/FGTestApi/TestDataLogger.hxx"
 #include "test_suite/FGTestApi/testGlobals.hxx"
+#include "test_suite/FGTestApi/testStringUtils.hxx"
 
 #include <simgear/math/sg_geodesy.hxx>
 #include <AIModel/AIAircraft.hxx>
@@ -120,9 +121,9 @@ void TrafficTests::testPushback()
     fgSetInt("/environment/metar/base-wind-dir-deg", 160);
 
     // Time to depart
-    std::string dep = getTimeString(30);
+    std::string dep = FGTestApi::strings::getTimeString(30);
     // Time to arrive
-    std::string arr = getTimeString(320);
+    std::string arr = FGTestApi::strings::getTimeString(320);
 
     const int radius = 18.0;
     const int cruiseAltFt = 32000;
@@ -181,9 +182,9 @@ void TrafficTests::testPushbackCargo()
     fgSetString("/sim/presets/airport-id", "EGPH");
 
     // Time to depart
-    std::string dep = getTimeString(30);
+    std::string dep = FGTestApi::strings::getTimeString(30);
     // Time to arrive
-    std::string arr = getTimeString(320);
+    std::string arr = FGTestApi::strings::getTimeString(320);
 
 
     FGAISchedule* schedule = new FGAISchedule(
@@ -240,9 +241,9 @@ void TrafficTests::testPushbackCargoInProgress()
     fgSetString("/sim/presets/airport-id", "EGPH");
 
     // Time to depart
-    std::string dep = getTimeString(-100);
+    std::string dep = FGTestApi::strings::getTimeString(-100);
     // Time to arrive
-    std::string arr = getTimeString(190);
+    std::string arr = FGTestApi::strings::getTimeString(190);
 
 
     FGAISchedule* schedule = new FGAISchedule(
@@ -301,9 +302,9 @@ void TrafficTests::testPushbackCargoInProgressDownWindEast()
     fgSetString("/sim/presets/airport-id", "EGPH");
 
     // Time to depart
-    std::string dep = getTimeString(-100);
+    std::string dep = FGTestApi::strings::getTimeString(-100);
     // Time to arrive
-    std::string arr = getTimeString(190);
+    std::string arr = FGTestApi::strings::getTimeString(190);
 
 
     FGAISchedule* schedule = new FGAISchedule(
@@ -362,9 +363,9 @@ void TrafficTests::testPushbackCargoInProgressDownWindWest()
     fgSetString("/sim/presets/airport-id", "EGPH");
 
     // Time to depart
-    std::string dep = getTimeString(-100);
+    std::string dep = FGTestApi::strings::getTimeString(-100);
     // Time to arrive
-    std::string arr = getTimeString(190);
+    std::string arr = FGTestApi::strings::getTimeString(190);
 
 
     FGAISchedule* schedule = new FGAISchedule(
@@ -423,9 +424,9 @@ void TrafficTests::testPushbackCargoInProgressNotBeyond()
     fgSetString("/sim/presets/airport-id", "EGPH");
 
     // Time to depart
-    std::string dep = getTimeString(-100);
+    std::string dep = FGTestApi::strings::getTimeString(-100);
     // Time to arrive
-    std::string arr = getTimeString(190);
+    std::string arr = FGTestApi::strings::getTimeString(190);
 
 
     FGAISchedule* schedule = new FGAISchedule(
@@ -485,9 +486,9 @@ void TrafficTests::testPushbackCargoInProgressNotBeyondNorth()
     fgSetString("/sim/presets/airport-id", "EGPH");
 
     // Time to depart
-    std::string dep = getTimeString(-100);
+    std::string dep = FGTestApi::strings::getTimeString(-100);
     // Time to arrive
-    std::string arr = getTimeString(190);
+    std::string arr = FGTestApi::strings::getTimeString(190);
 
 
     FGAISchedule* schedule = new FGAISchedule(
@@ -547,9 +548,9 @@ void TrafficTests::testPushbackCargoInProgressBeyond()
     fgSetString("/sim/presets/airport-id", "EGPH");
 
     // Time to depart
-    std::string dep = getTimeString(-100);
+    std::string dep = FGTestApi::strings::getTimeString(-100);
     // Time to arrive
-    std::string arr = getTimeString(190);
+    std::string arr = FGTestApi::strings::getTimeString(190);
 
 
     FGAISchedule* schedule = new FGAISchedule(
@@ -610,9 +611,9 @@ void TrafficTests::testPushbackCargoInProgressBeyondNorth()
     fgSetString("/sim/presets/airport-id", "EGPH");
 
     // Time to depart
-    std::string dep = getTimeString(-100);
+    std::string dep = FGTestApi::strings::getTimeString(-100);
     // Time to arrive
-    std::string arr = getTimeString(190);
+    std::string arr = FGTestApi::strings::getTimeString(190);
 
 
     FGAISchedule* schedule = new FGAISchedule(
@@ -676,9 +677,9 @@ void TrafficTests::testChangeRunway()
     fgSetInt("/environment/metar/base-wind-dir-deg", 160);
 
     // Time to depart
-    std::string dep = getTimeString(60);
+    std::string dep = FGTestApi::strings::getTimeString(60);
     // Time to arrive
-    std::string arr = getTimeString(320);
+    std::string arr = FGTestApi::strings::getTimeString(320);
 
     const int radius = 24.0;
     const int cruiseAltFt = 32000;
@@ -735,9 +736,9 @@ void TrafficTests::testPushforward()
     fgSetString("/sim/presets/airport-id", departureAirport->getId());
 
     // Time to depart
-    std::string dep = getTimeString(60);
+    std::string dep = FGTestApi::strings::getTimeString(60);
     // Time to arrive
-    std::string arr = getTimeString(320);
+    std::string arr = FGTestApi::strings::getTimeString(320);
 
     const int radius = 8.0;
     const int cruiseAltFt = 32000;
@@ -793,9 +794,9 @@ void TrafficTests::testPushforwardSpeedy()
     fgSetString("/sim/presets/airport-id", departureAirport->getId());
 
     // Time to depart
-    std::string dep = getTimeString(60);
+    std::string dep = FGTestApi::strings::getTimeString(60);
     // Time to arrive
-    std::string arr = getTimeString(320);
+    std::string arr = FGTestApi::strings::getTimeString(320);
 
     const int radius = 8.0;
     const int cruiseAltFt = 32000;
@@ -852,9 +853,9 @@ void TrafficTests::testPushforwardParkYBBN()
     fgSetString("/sim/presets/airport-id", arrivalAirport->getId());
 
     // Time to depart
-    std::string dep = getTimeString(60);
+    std::string dep = FGTestApi::strings::getTimeString(60);
     // Time to arrive
-    std::string arr = getTimeString(3260);
+    std::string arr = FGTestApi::strings::getTimeString(3260);
 
     const int radius = 8.0;
     const int cruiseAltFt = 32000;
@@ -929,11 +930,11 @@ void TrafficTests::testPushforwardParkYBBNRepeatGa()
     fgSetString("/sim/presets/airport-id", arrivalAirport->getId());
 
     // Time to depart
-    std::string dep = getTimeString(120);
+    std::string dep = FGTestApi::strings::getTimeString(120);
     // Time to arrive
-    std::string arr = getTimeString(3260);
+    std::string arr = FGTestApi::strings::getTimeString(3260);
     // Time to arrive back
-    std::string ret = getTimeString(6460);
+    std::string ret = FGTestApi::strings::getTimeString(6460);
 
     const int radius = 8.0;
     const int cruiseAltFt = 32000;
@@ -1005,11 +1006,11 @@ void TrafficTests::testPushforwardParkYBBNRepeatGaDelayed()
     fgSetString("/sim/presets/airport-id", arrivalAirport->getId());
 
     // Time to depart
-    std::string dep = getTimeString(120);
+    std::string dep = FGTestApi::strings::getTimeString(120);
     // Time to arrive
-    std::string arr = getTimeString(3260);
+    std::string arr = FGTestApi::strings::getTimeString(3260);
     // Time to arrive back
-    std::string ret = getTimeString(6460);
+    std::string ret = FGTestApi::strings::getTimeString(6460);
 
     const int radius = 8.0;
     const int cruiseAltFt = 32000;
@@ -1102,11 +1103,11 @@ void TrafficTests::testPushforwardParkYBBNRepeatGate()
     fgSetString("/sim/presets/airport-id", arrivalAirport->getId());
 
     // Time to depart
-    std::string dep = getTimeString(10);
+    std::string dep = FGTestApi::strings::getTimeString(10);
     // Time to arrive
-    std::string arr = getTimeString(3260);
+    std::string arr = FGTestApi::strings::getTimeString(3260);
     // Time to arrive back
-    std::string ret = getTimeString(6460);
+    std::string ret = FGTestApi::strings::getTimeString(6460);
 
     const int radius = 32.0;
     const int cruiseAltFt = 32000;
@@ -1283,13 +1284,3 @@ FGAIAircraft * TrafficTests::flyAI(SGSharedPtr<FGAIAircraft> aiAircraft, std::st
     (*csvFile).close();
     return aiAircraft;
 }
-
-std::string TrafficTests::getTimeString(int timeOffset)
-{
-    char ret[11];
-    time_t rawtime = globals->get_time_params()->get_cur_time();
-    rawtime = rawtime + timeOffset;
-    tm* timeinfo = gmtime(&rawtime);
-    strftime(ret, 11, "%w/%H:%M:%S", timeinfo);
-    return ret;
-}
